/*
 * Copyright (c) 2007 - 2011 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject
 *
 * de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * Koelner Strasse 30
 * D-50859 Kln
 * +49 (0)2234 4301 800
 * info@invat.de
 * www.inovat.de
 */

package de.bsvrz.sys.funclib.kbgen;

import de.bsvrz.dav.daf.main.config.SystemObjectType;

import java.util.ArrayList;
import java.util.List;

/**
 * Reprsentiert ein Stellvertreterobjekt fr ein {@link de.bsvrz.dav.daf.main.config.ConfigurationObject}.
 * Dieses Stellvertreterobjekt hlt alle Informationen eines {@link de.bsvrz.dav.daf.main.config.ConfigurationObject}
 * einschlielich der Daten der konfigurierenden Attributgruppen. Aus diesen Informationen wird dann ber ein Objekt der
 * Klasse {@link ConfigAreaCreator} ein Konfigurationsbereich erzeugt. Das Proxyobjekt enthlt damit alle Informatioen,
 * die spter (nach der Erzeugung des Konfigurationsbereichs) aus der Konfiguration zu dem entsprechenden Objekt
 * ermittelt werden knnen.
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kni (HCK)
 * @version $Revision: 513 $ / $Date: 2011-04-13 14:23:45 +0200 (Mi, 13 Apr 2011) $ / ($Author: HCK $)
 */

public class ProxyConfigurationObject implements Cloneable {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Private ----------------------------------------------------------------
	private final String _pid;
	private final String _name;
	private final SystemObjectType _type;
	private List<ProxyDataDescription> _proxyConfigurationDataList = new ArrayList<ProxyDataDescription>();
	private List<ProxySetDescription> _proxySetList = new ArrayList<ProxySetDescription>();

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeugt ein Objekt vom Typ ProxyConfigurationObject
	 *
	 * @param pid Die PID des zu erzeugenden ProxyObjekts.
	 * @param name Der Name des zu erzeugenden ProxyObjekts.
	 * @param type Der Typ des zu erzeugenden ProxyObjekts.
	 */
	public ProxyConfigurationObject(String pid, String name, SystemObjectType type) {
		_pid = pid;
		_name = name;
		_type = type;
	}

// ------------------------------------------------------------------------
// GETTER / SETTER METHODEN
// ------------------------------------------------------------------------

	public String getName() {
		return _name;
	}

	public String getPid() {
		return _pid;
	}

	public List<ProxyDataDescription> getProxyConfigurationDataList() {
		return _proxyConfigurationDataList;
	}

	public List<ProxySetDescription> getProxySetList() {
		return _proxySetList;
	}

	public SystemObjectType getType() {
		return _type;
	}

// ------------------------------------------------------------------------
// KANONISCHE METHODEN
// ------------------------------------------------------------------------

	/**
	 * Gibt die String-Reprsentation dieses Objekts aus.
	 * <p/>
	 * Die Formatierung der Ausgabe kann sich ndern und wird nicht garantiert.
	 *
	 * @return Aktueller Zustand der Klassenvariablen dieses Objekts.
	 */
	public String toString() {
		return "ProxyConfigurationObject{" + "_pid='" + _pid + '\'' + ", _name='" + _name + '\'' + ", _type=" + _type + ", _proxyConfigurationDataList=" + _proxyConfigurationDataList + ", _proxySetList=" + _proxySetList + '}';
	}

// ------------------------------------------------------------------------
// SONSTIGE METHODEN
// ------------------------------------------------------------------------

	public void addConfigurationData(ProxyDataDescription proxyDataDescription) {
		_proxyConfigurationDataList.add(proxyDataDescription);
	}

	public void addSet(ProxySetDescription proxySetDescription) {
		_proxySetList.add(proxySetDescription);
	}
}
